DiagnosticsReferenceProperty class final
- Inheritance
-
- Object
- DiagnosticsProperty
- DiagnosticsReferenceProperty
Constructors
- DiagnosticsReferenceProperty({required String name, required DiagnosticsLevel level, required ReferenceKind referenceKind, required String value})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- level → DiagnosticsLevel
-
final
- name → String
-
final
- referenceKind → ReferenceKind
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
final
Methods
-
copyWith(
{String? name, DiagnosticsLevel? level, ReferenceKind? referenceKind, String? value}) → DiagnosticsReferenceProperty -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override