StatefulSeed class abstract
- Inheritance
- Implementers
Constructors
- StatefulSeed({Key? key})
-
Creates a stateful seed, optionally
keyed.const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Identity Key used by keyed reconciliation (Branch.updateChildren).
Null means positional (unkeyed) identity.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createBranch(
) → StatefulBranch -
Creates the mounted Branch for this configuration.
override
-
createState(
) → State< StatefulSeed> - Creates the mutable state for a branch of this seed.
-
debugFillProperties(
List< DiagnosticsProperty> properties) → void -
Adds this object's diagnostic properties to
properties.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
toStringDeep(
) → String -
Returns a deterministic multiline description of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited